@@ -173,7 +173,7 @@ int game()
                 bonusplot();
                 scoreadd();
                 update_show_strength();
-                texthandler();
+                texthandler(1);
                 seeifdead();
 //makesounds();
                 wakeupal(xpos, ypos);
@@ -217,7 +217,7 @@ int game()
 
 void showtext()
 {
-    texthandler();
+    texthandler(0);
     switchbank();
 }
 
@@ -426,7 +426,6 @@ void setup()
     initweapon();
     initprojtab();
     initbultab();
-    setfullclip();
     initrockettab();
     getvars();
     prepstrength();
@@ -480,6 +479,7 @@ int main(int argc, char** argv)
 
     SDL_Init(SDL_INIT_VIDEO|SDL_INIT_AUDIO);
     SDL_WM_SetCaption("Asylum", "Asylum");
+    SDL_EnableUNICODE(1);
 #ifndef _NO_SOUND
     init_audio();
 #endif
@@ -522,7 +522,6 @@ char deathmusicpath[] = "./Resources/Music2";
 int getfiles()
 {
     getvitalfiles();
-    setfullclip();
     showloading();
     init_sounds();
     getmusicfiles();
