@@ -261,24 +261,27 @@ void wipetexttab()
         *(r10++) = 0;
 }
 
-void texthandler()
+void texthandler(int do_animation)
 {
     textinfo* r11 = texttabofs;
     int r9 = _textno;
 
     for (; r9 > 0; r11++, r9--)
     {
-       loopa6: if (r11->count == 0) continue;
-       textproc:;
-        int r4 = (frameinc > 4) ? 4 : frameinc;
-        r11->count -= r4; if (r11->count < 0) r11->count = 0;
+        if (r11->count == 0) continue;
 
-        for (; r4 > 0; r4--)
+        if (do_animation)
         {
-           loopb1:
-            r11->x += r11->dx;
-            r11->y += r11->dy;
+            int r4 = (frameinc > 4) ? 4 : frameinc;
+            r11->count -= r4; if (r11->count < 0) r11->count = 0;
+
+            for (; r4 > 0; r4--)
+            {
+                r11->x += r11->dx;
+                r11->y += r11->dy;
+            }
         }
+
         int XxX = r11->x>>8;
         int YyY = r11->y>>8;
         for (char* r10 = r11->text; *r10 != 0; r10++)
@@ -542,14 +545,6 @@ void showscore(char plscore[8])
     }
 }
 
-void setfullclip()
-{
-    clip.x = vduvar.gamex; clip.y = vduvar.gamey;
-    clip.w = vduvar.gamew;
-    clip.h = vduvar.gameh;
-    writeclip();
-}
-
 void writeclip()
 {
     swi_fastspr_setclipwindow(clip.x, clip.y, clip.x+clip.w, clip.y+clip.h);
@@ -589,8 +584,16 @@ void showgamescreen()
     releaseclip();
     //SDL_BlitSurface(GameScreen, NULL, ArcScreen, NULL);
     fspplot(&GameScreen, 0, 0, 0);
+    #if 0
     if (!vduvar.opengl) switchbank();
+    #endif
+
+    clip.x = vduvar.gamex;
+    clip.y = vduvar.gamey;
+    clip.w = vduvar.gamew;
+    clip.h = vduvar.gameh;
     writeclip();
+
     scorewiperead();
     showlives();
 }
@@ -600,8 +603,15 @@ void showchatscreen()
     releaseclip();
     //SDL_BlitSurface(ChatScreen, NULL, ArcScreen, NULL);
     fspplot(&ChatScreen, 0, 0, 0);
+    #if 0
     switchbank();
     if (vduvar.opengl) fspplot(&ChatScreen, 0, 0, 0);
+    #endif
+
+    clip.x = 20;
+    clip.y = 20;
+    clip.w = 319 - 20*2;
+    clip.h = 255 - 20*2;
     writeclip();
 }
 
@@ -666,11 +676,11 @@ void init_strengthcol()
     {
 	glBindTexture(GL_TEXTURE_2D, *redtex);
         gluBuild2DMipmaps(GL_TEXTURE_2D, GL_RGBA, 128, 64,
-			  GL_RGBA, GL_UNSIGNED_BYTE, (char*)redpixels);
+			  GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, (char*)redpixels);
         free(redpixels);
 	glBindTexture(GL_TEXTURE_2D, *greytex);
         gluBuild2DMipmaps(GL_TEXTURE_2D, GL_RGBA, 128, 64,
-			  GL_RGBA, GL_UNSIGNED_BYTE, (char*)greypixels);
+			  GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, (char*)greypixels);
         free(greypixels);
     }
     else
@@ -744,7 +754,7 @@ void decomp(fastspr_sprite* DecompScreen, char* r11)
     {
         DecompScreen->x = -1;  DecompScreen->y = -1;
         gluBuild2DMipmaps(GL_TEXTURE_2D, GL_RGBA, 512, 512,
-			  GL_RGBA, GL_UNSIGNED_BYTE, (char*)data);
+			  GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, (char*)data);
         free(data);
     }
     else
@@ -816,7 +826,7 @@ void backprep(char* backadr)
 	glGenTextures(1, batex);
 	glBindTexture(GL_TEXTURE_2D, *batex);
 	gluBuild2DMipmaps(GL_TEXTURE_2D, 4, 2*64, 2*32,
-			  GL_RGBA, GL_UNSIGNED_BYTE, (char*)ba);
+			  GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, (char*)ba);
     }
     else
     {
@@ -982,7 +992,7 @@ int initialize_sprites(char* start, fastspr_sprite* sprites, int max_sprites, ch
 	    //Without this line I don't get textures unless I use gluBuild2DMipmaps
 	    glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST); 
 	    glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA, 256, 256, 0,
-			 GL_RGBA, GL_UNSIGNED_BYTE, (char*)data);
+			 GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, (char*)data);
 	    free(data);
 	}
 	else SDL_UnlockSurface(sprites[i].s);
